@@ -1402,6 +1402,7 @@ struct Outgoing final {
   bool lowercase CXX_DEFAULT_VALUE(false);
   ::std::uint64_t max_busy_dot_probes CXX_DEFAULT_VALUE(0);
   ::std::uint64_t max_qperq CXX_DEFAULT_VALUE(0);
+  ::std::uint64_t max_bytesperq CXX_DEFAULT_VALUE(0);
   ::std::uint64_t max_ns_address_qperq CXX_DEFAULT_VALUE(0);
   ::std::uint64_t max_ns_per_resolve CXX_DEFAULT_VALUE(0);
   ::std::uint64_t network_timeout CXX_DEFAULT_VALUE(0);
@@ -1432,6 +1433,7 @@ struct Outgoing final {
 struct Packetcache final {
   bool disable CXX_DEFAULT_VALUE(false);
   ::std::uint64_t max_entries CXX_DEFAULT_VALUE(0);
+  ::std::uint64_t max_entry_size CXX_DEFAULT_VALUE(0);
   ::std::uint64_t ttl CXX_DEFAULT_VALUE(0);
   ::std::uint64_t negative_ttl CXX_DEFAULT_VALUE(0);
   ::std::uint64_t servfail_ttl CXX_DEFAULT_VALUE(0);
@@ -1497,6 +1499,7 @@ struct Recordcache final {
   ::std::uint64_t max_cache_bogus_ttl CXX_DEFAULT_VALUE(0);
   ::std::uint64_t max_entries CXX_DEFAULT_VALUE(0);
   ::std::uint64_t max_ttl CXX_DEFAULT_VALUE(0);
+  ::std::uint64_t max_entry_size CXX_DEFAULT_VALUE(0);
   bool limit_qtype_any CXX_DEFAULT_VALUE(false);
   ::std::uint64_t max_rrset_size CXX_DEFAULT_VALUE(0);
   ::std::uint64_t max_negative_ttl CXX_DEFAULT_VALUE(0);
